<?php

namespace Beo\Career\Http\Controllers;

use Exception;
use Litepie\Http\Controllers\ResourceController as BaseController;
use Litepie\Database\RequestScope;
use Beo\Career\Forms\Profile as ProfileForm;
use Beo\Career\Http\Requests\ProfileRequest;
use Beo\Career\Http\Resources\ProfileResource;
use Beo\Career\Http\Resources\ProfilesCollection;
use Beo\Career\Models\Profile;
use Beo\Career\Scopes\ProfileResourceScope;


/**
 * Resource controller class for profile.
 */
class ProfileResourceController extends BaseController
{

    /**
     * Initialize profile resource controller.
     *
     *
     * @return null
     */
    public function __construct()
    {
        parent::__construct();
        $this->form = ProfileForm::grouped(false)
                        ->setAttributes()
                        ->toArray();
        $this->modules = $this->modules(config('beo.career.modules'), 'career', guard_url('career'));
    }

    /**
     * Display a list of profile.
     *
     * @return Response
     */
    public function index(ProfileRequest $request)
    {

        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Profile::pushScope(new RequestScope())
            ->pushScope(new ProfileResourceScope())
            ->simplePaginate($pageLimit);

        $data = new ProfilesCollection($page);

        $form = $this->form;
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('career::profile.names'))
            ->view('career::profile.index')
            ->data(compact('data', 'modules', 'form'));
    }

    /**
     * Display profile.
     *
     * @param Request $request
     * @param Model   $profile
     *
     * @return Response
     */
    public function show(ProfileRequest $request, Profile $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new ProfileResource($model);

        return $this->response
            ->setMetaTitle(trans('app.view') . ' ' . trans('career::profile.name'))
            ->data(compact('data', 'form', 'modules'))
            ->view('career::profile.show');
    }

    /**
     * Show the form for creating a new profile.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ProfileRequest $request, Profile $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new ProfileResource($model);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('career::profile.name'))
            ->view('career::profile.create')
            ->data(compact('data', 'form', 'modules'));
    }

    /**
     * Create new profile.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ProfileRequest $request, Profile $model)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $attributes['user_type'] = user_type();
            $model->create($attributes);
            $data = new ProfileResource($model);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('career::profile.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('career/profile/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/career/profile'))
                ->redirect();
        }

    }

    /**
     * Show profile for editing.
     *
     * @param Request $request
     * @param Model   $profile
     *
     * @return Response
     */
    public function edit(ProfileRequest $request, Profile $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new ProfileResource($model);

        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('career::profile.name'))
            ->view('career::profile.edit')
            ->data(compact('data', 'form', 'modules'));
    }

    /**
     * Update the profile.
     *
     * @param Request $request
     * @param Model   $profile
     *
     * @return Response
     */
    public function update(ProfileRequest $request, Profile $model)
    {
        try {
            $attributes = $request->all();
            $model->update($attributes);
            $data = new ProfileResource($model);

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('career::profile.name')]))
                ->code(204)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('career/profile/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('career/profile/' .  $model->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the profile.
     *
     * @param Model   $profile
     *
     * @return Response
     */
    public function destroy(ProfileRequest $request, Profile $model)
    {
        try {
            $model->delete();
            $data = new ProfileResource($model);

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('career::profile.name')]))
                ->code(202)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('career/profile/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('career/profile/' .  $model->getRouteKey()))
                ->redirect();
        }

    }
}
